@@ -1,7 +1,7 @@
 import subprocess  # nosec - skip B404:blacklist
 import logging
 import shlex
-from click.testing import CliRunner
+from click.testing import CliRunner, Result
 logger = logging.getLogger(__name__)
 
 
@@ -13,11 +13,12 @@ def run_shell_command(command: str):
     logger.info(f"{command} response: {response}")
 
 
-def run_click_command(click_function_to_run, args: str) -> str:
+def run_click_command(click_function_to_run, args: str) -> Result:
     """
     Given a python method that runs a click command, use the click.testing.CliRunner to run the command with arguments provided as a string
     """
     runner = CliRunner()
+    logger.debug(f"Running with args: '{args}")
     args = shlex.split(args)
-    result = runner.invoke(click_function_to_run, args)
-    return result
+    response = runner.invoke(cli=click_function_to_run, args=args, catch_exceptions=False)
+    return response
