@@ -1,9 +1,8 @@
 import os
 import unittest
-import yaml
 import json
 import logging
-from kinnaird_utils.files.files import read_yaml_file
+from kinnaird_utils.files import read_yaml_file
 
 logger = logging.getLogger(__name__)
 
